==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ArbitraryFSAccessThroughSMsConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ArbitraryFSAccessThroughSMsConfigFluent<A extends ArbitraryFSAccessThroughSMsConfigFluent<A>> extends BaseFluent<A>{
  public ArbitraryFSAccessThroughSMsConfigFluent() {
  }
  public ArbitraryFSAccessThroughSMsConfigFluent(ArbitraryFSAccessThroughSMsConfig instance) {
    instance = (instance != null ? instance : new ArbitraryFSAccessThroughSMsConfig());

    if (instance != null) {
      this.withDeny(instance.getDeny());
      this.withDeny(instance.getDeny());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean deny;
  private Map<String,Object> additionalProperties;
  public Boolean getDeny() {
    return this.deny;
  }
  public A withDeny(Boolean deny) {
    this.deny=deny; return (A) this;
  }
  public boolean hasDeny() {
    return this.deny != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ArbitraryFSAccessThroughSMsConfigFluent that = (ArbitraryFSAccessThroughSMsConfigFluent) o;
    if (!java.util.Objects.equals(deny, that.deny)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deny,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deny != null) { sb.append("deny:"); sb.append(deny + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withDeny() {
    return withDeny(true);
  }
  
}

==> openshift-model-monitoring-6.9.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ArbitraryFSAccessThroughSMsConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ArbitraryFSAccessThroughSMsConfigFluent<A extends ArbitraryFSAccessThroughSMsConfigFluent<A>> extends BaseFluent<A>{
  public ArbitraryFSAccessThroughSMsConfigFluent() {
  }
  
  public ArbitraryFSAccessThroughSMsConfigFluent(ArbitraryFSAccessThroughSMsConfig instance) {
    this.copyInstance(instance);
  }
  private Boolean deny;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ArbitraryFSAccessThroughSMsConfig instance) {
    instance = (instance != null ? instance : new ArbitraryFSAccessThroughSMsConfig());
    if (instance != null) {
          this.withDeny(instance.getDeny());
          this.withDeny(instance.getDeny());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getDeny() {
    return this.deny;
  }
  
  public A withDeny(Boolean deny) {
    this.deny = deny;
    return (A) this;
  }
  
  public boolean hasDeny() {
    return this.deny != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ArbitraryFSAccessThroughSMsConfigFluent that = (ArbitraryFSAccessThroughSMsConfigFluent) o;
    if (!java.util.Objects.equals(deny, that.deny)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(deny,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deny != null) { sb.append("deny:"); sb.append(deny + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDeny() {
    return withDeny(true);
  }
  

}
